' Finite element program written by Charles G. Dietz
' 2D model incorporating grids, beams, and quads
' PowerBasic 9.00 (32 bit compiler)
' Version 1.21 (10-20-2007)
'  - fixed file association with REMOVE$(COMMAND$, """")
'  - allow "$" comments anywhere on data line
' Version 1.22 (09-12-2008)
'  - corrected bug for BEAM with PIN (r3 & r4 should not be 0)
' Version 1.23 (09-19-2008)
'  - set displayed bending moment f3 = 0 for BEAM with PIN (see Stress)
' Version 1.24 (10-12-2009), compiler 9.02
'  - replaced ISFILE(dataFolder) with folderExists()... compiler 9.02 changed
' Version 1.25 (05-25-2010), compiler 9.04
'  - changed data storage from _DOCUMENTS to _APPDATA
'  - replaced folderExist() back with ISFILE()... compiler 9.04 corrected ISFOLDER()
' Version 1.26 (05-27-2011), compiler 9.05
'  - resizeable main textbox dialog
' Version 1.27 (05-28-2011), compiler 9.05
'  - resizeable dialog for displaying solution and plot dialogs
' Version 1.28 (06-08-2011), compiler 9.05
'  - corrected bug associated with copying results (changed to static sClipbd)
' Version 1.29 (10-12-2011), compiler 9.05
'  - corrected vonM sign error on last term found by Zensin
' Version 1.30 (10-19-2011), compiler 9.05
'  - set focus to textbox after loading data file (so first mouse click doesn't jump to top)
' Version 1.31 (10-20-2011), compiler 9.05
'  - include solution titles with clip board copy
'  - jazzed up the 'About' dialog box
' Version 1.32 (10-22-2011), compiler 9.05
'  - corrected runtime error in printSoln()... nOpt made TI() out of range
'  - corrected plot error as plot dialog resized with changed aspect ratio (not done yet)
'  - used newer GLOBAL syntax with multiple variables on a line
' Version 1.40 (02-08-2012), compiler 10.03
'  - recoded print routines using XPRINT
'  - recoded plot routines using a GRAPHICS control
'  - added 'Plot Model' item to Files Menu (don't need to first run the model)
'  - changed the dialogs from modal to modeless 
' Version 1.41 (05-02-2012), compiler 10.03 
'  - fixed plotting problem (needed abs(u) and abs(v) for calculating uMax)
'  - disabled 'Soln' and 'Plot' button on reset
'-------------------------------------------------------------------------------------------------------------
$progID = "FE2D"
$HelpFile = "FE2d.hlp"
$SyntaxFile = "FE2dSyn.hlp"
$Comment = "$"
%ID_TextBox = 100
'----- Menu items
%ID_New = 201
%ID_Open = 202
%ID_Save = 203
%ID_SaveAs = 204
%ID_Print = 205
%ID_Plot = 206
%ID_Exit = 207
%ID_Reset = 221
%ID_Run = 222
%ID_Disp = 223
%ID_PlotDefm = 224
%ID_Help = 231
%ID_Syntax = 232
%ID_About = 233
'----- Toolbar items
%ID_ToolBar = 300
%ID_OpenTB = 301
%ID_SaveTB = 302
%ID_PrintTB = 303
%ID_RunTB = 304
%ID_SolnTB = 305
%ID_PlotTB = 306
%ID_QuitTB = 307
%ID_Output = 500
%ID_Subcase = 600
'----- Result items
%ID_Hdr0 = 700
%ID_Hdr1 = 701
%ID_Hdr2 = 702
%ID_Hdr3 = 703
%ID_Hdr4 = 704
%ID_Hdr5 = 705
%ID_Hdr6 = 706
%ID_Results = 707
%ID_PrintResults = 708
%ID_Copy = 709
%ID_AvgStress = 710
%ID_Deflns = 711
%ID_Reacts = 712
%ID_Forces = 713
%ID_Stress = 714
'----- Plot items
%ID_Graphic  = 800
%ID_DefmScrl = 801
%ID_GridNum  = 802
%ID_Line     = 803
%ID_Label1   = 804
%ID_Label2   = 805
'----- print items
%ID_Listbox = 900
%ID_Status  = 950

GLOBAL hDlg, hModelDlg, hSubcaseDlg, hDispDlg, hPlotDlg, hTB AS LONG
GLOBAL gOrigTBProc, hMenu, hFileMenu, hSolveMenu, hHelpMenu, hStatus AS LONG
GLOBAL neq, npr, nStiff, cmax, rms, showGridNums, hPlotRgn, hPlotBrush AS LONG
GLOBAL fileChanged, kStorData, doNotQuit, runPhase, kRot, av, prn AS BYTE
GLOBAL dataFolder, thisFile, nameOfFile, fontType, sErr, sModel, sSolve  AS STRING
GLOBAL nGrids, nPolars, nBeams, nQuads, nProps, nMatls, nSprgs AS LONG
GLOBAL nSubcases, numLines, numGrids, numBeams, numQuads AS LONG
GLOBAL lineCursor, lineEndModel, hScroll, scrlPos AS LONG
GLOBAL rad, eTol, gx, gy AS DOUBLE
GLOBAL si AS SCROLLINFO, di AS DOCINFO
GLOBAL defaultPrn AS ASCIIZ * 32
global selectedPrinter as string
'GLOBAL gLastPrinterSelected AS STRING


'Global arrays
GLOBAL modelData() AS STRING
GLOBAL CBM() AS DOUBLE
GLOBAL CQD() AS DOUBLE
GLOBAL CORD() AS DOUBLE
GLOBAL NBM() AS LONG
GLOBAL NQD() AS LONG                                                        '
GLOBAL DOF() AS LONG
GLOBAL XGR() AS LONG
GLOBAL XBM() AS LONG
GLOBAL XQD() AS LONG
GLOBAL KD() AS LONG
GLOBAL STF() AS DOUBLE
GLOBAL D() AS DOUBLE
GLOBAL XII() AS DOUBLE
GLOBAL ETA() AS DOUBLE
GLOBAL GAUSS() AS DOUBLE
GLOBAL B() AS DOUBLE
GLOBAL P() AS DOUBLE
GLOBAL PR() AS DOUBLE
GLOBAL FBM() AS DOUBLE
GLOBAL FQD() AS DOUBLE
GLOBAL FLC() AS DOUBLE
global defm() as double
'GLOBAL UNDEFMBM() AS DOUBLE
'GLOBAL DEFMBM() AS DOUBLE
'GLOBAL UNDEFMQD() AS DOUBLE
'GLOBAL DEFMQD() AS DOUBLE


'runStatus  = 0   Must reprocess model
'           = 1   Must perform decomposition
'           = 2   Can solve load cases

'---------------------------------------------------------------------------
'model    CBM  CQD  CORD  NBM  NQD  DOF  POLR  PDAT  EDAT  NSEQ
'kcol                     NBM  NQD  DOF                          KD
'stiff    CBM  CQD  CORD  NBM  NQD  DOF                          KD
'trfm               CORD            DOF                          KD
'dcomp              CORD            DOF                          KD
'load     CBM  CQD  CORD  NBM  NQD  DOF  PR    P     FBM   FQD
'rhsol                                         P                 KD
'stress   CBM  CQD  CORD  NBM  NQD  DOF  PR    P     FBM   FQD
'show                     NBM  NQD  DOF  PR    P     FBM   FQD
'
'CBM(nBeams,13)   r1  r2  r3  r4  b  v  alfa  rho  A  ecc1  ecc2  bcol  u
'CQD(nQuads,43)   alfa  rho  t  D1  D2  D3  D4  KQD...
'CORD(nGrids,6)   x   y   angl  k1  k2  k3
'NBM(nBeams,3)    n1  n2  type
'NQD(nQuads,4)    n1  n2  n3  n4
'DOF(nGrids,4)    u1  u2  u3  iRot
'POLR(nGrids,2)   xc  yc
'PDAT(nProps,4)   A   I  v  bcol
'EDAT(nMatls,4)   E   v  alfa  rho
'NSEQ(nGrids)     Ni
'PR(npr)          P   R
'P(neq)           P
'FBM(nBeams,6)    F1  F2  F3  F4  F5  F6
'FQD(nQuads,12)   (Sx, Sy, Sxy) at four Gauss points
'KD(neq+1)        Diag
'---------------------------------------------------------------------------
